LogbotLogger class

Constructors

LogbotLogger()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

critical({required String title, dynamic message, StackTrace? stackTrace}) → void
debug({required String title, dynamic message, StackTrace? stackTrace}) → void
error({required String title, dynamic message, StackTrace? stackTrace}) → void
info({required String title, dynamic message, StackTrace? stackTrace}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
simple(String message) → void
toString() String
A string representation of this object.
inherited
verbose({required String title, dynamic message, StackTrace? stackTrace}) → void
warning({required String title, dynamic message, StackTrace? stackTrace}) → void
wrapText(String text) String
UTILITY

Operators

operator ==(Object other) bool
The equality operator.
inherited